INSERT INTO tiki_preferences VALUES ('allowRegister','n');
INSERT INTO tiki_preferences VALUES ('anonCanEdit','n');
INSERT INTO tiki_preferences VALUES ('article_comments_default_ordering','points_desc');
INSERT INTO tiki_preferences VALUES ('article_comments_per_page','10');
INSERT INTO tiki_preferences VALUES ('art_list_author','y');
INSERT INTO tiki_preferences VALUES ('art_list_date','y');
INSERT INTO tiki_preferences VALUES ('art_list_expire','y');
INSERT INTO tiki_preferences VALUES ('art_list_img','y');
INSERT INTO tiki_preferences VALUES ('art_list_reads','y');
INSERT INTO tiki_preferences VALUES ('art_list_size','y');
INSERT INTO tiki_preferences VALUES ('art_list_title','y');
INSERT INTO tiki_preferences VALUES ('art_list_topic','y');
INSERT INTO tiki_preferences VALUES ('art_list_type','y');
INSERT INTO tiki_preferences VALUES ('art_list_visible','y');
INSERT INTO tiki_preferences VALUES ('auth_create_user_auth','n');
INSERT INTO tiki_preferences VALUES ('auth_create_user_tiki','n');
INSERT INTO tiki_preferences VALUES ('auth_type','LDAP');
INSERT INTO tiki_preferences VALUES ('auth_pear_host','localhost');
INSERT INTO tiki_preferences VALUES ('auth_pear_port','389');
INSERT INTO tiki_preferences VALUES ('auth_imap_pop3_basedsn','');
INSERT INTO tiki_preferences VALUES ('auth_ldap_adminpass','');
INSERT INTO tiki_preferences VALUES ('auth_ldap_adminuser','');
INSERT INTO tiki_preferences VALUES ('auth_ldap_basedn','');
INSERT INTO tiki_preferences VALUES ('auth_ldap_groupattr','cn');
INSERT INTO tiki_preferences VALUES ('auth_ldap_groupdn','');
INSERT INTO tiki_preferences VALUES ('auth_ldap_groupoc','groupOfUniqueNames');
INSERT INTO tiki_preferences VALUES ('auth_ldap_memberattr','uniqueMember');
INSERT INTO tiki_preferences VALUES ('auth_ldap_memberisdn','n');
INSERT INTO tiki_preferences VALUES ('auth_ldap_scope','sub');
INSERT INTO tiki_preferences VALUES ('auth_ldap_userattr','uid');
INSERT INTO tiki_preferences VALUES ('auth_ldap_userdn','');
INSERT INTO tiki_preferences VALUES ('auth_ldap_useroc','inetOrgPerson');
INSERT INTO tiki_preferences VALUES ('auth_method','tiki');
INSERT INTO tiki_preferences VALUES ('auth_skip_admin','y');
INSERT INTO tiki_preferences VALUES ('blog_comments_default_ordering','points_desc');
INSERT INTO tiki_preferences VALUES ('blog_comments_per_page','10');
INSERT INTO tiki_preferences VALUES ('blog_list_activity','y');
INSERT INTO tiki_preferences VALUES ('blog_list_created','y');
INSERT INTO tiki_preferences VALUES ('blog_list_description','y');
INSERT INTO tiki_preferences VALUES ('blog_list_lastmodif','y');
INSERT INTO tiki_preferences VALUES ('blog_list_order','created_desc');
INSERT INTO tiki_preferences VALUES ('blog_list_posts','y');
INSERT INTO tiki_preferences VALUES ('blog_list_title','y');
INSERT INTO tiki_preferences VALUES ('blog_list_user','n');
INSERT INTO tiki_preferences VALUES ('blog_list_visits','y');
INSERT INTO tiki_preferences VALUES ('blog_spellcheck','n');
INSERT INTO tiki_preferences VALUES ('cacheimages','y');
INSERT INTO tiki_preferences VALUES ('cachepages','y');
INSERT INTO tiki_preferences VALUES ('change_language','y');
INSERT INTO tiki_preferences VALUES ('change_theme','y');
INSERT INTO tiki_preferences VALUES ('cms_bot_bar','y');
INSERT INTO tiki_preferences VALUES ('cms_left_column','y');
INSERT INTO tiki_preferences VALUES ('cms_right_column','y');
INSERT INTO tiki_preferences VALUES ('cms_spellcheck','n');
INSERT INTO tiki_preferences VALUES ('cms_top_bar','n');
INSERT INTO tiki_preferences VALUES ('contact_user','admin');
INSERT INTO tiki_preferences VALUES ('count_admin_pvs','y');
INSERT INTO tiki_preferences VALUES ('default_map','pacific.map');
INSERT INTO tiki_preferences VALUES ('directory_columns','3');
INSERT INTO tiki_preferences VALUES ('directory_links_per_page','20');
INSERT INTO tiki_preferences VALUES ('directory_open_links','n');
INSERT INTO tiki_preferences VALUES ('directory_validate_urls','n');
INSERT INTO tiki_preferences VALUES ('direct_pagination','n');
INSERT INTO tiki_preferences VALUES ('display_timezone','EST');
INSERT INTO tiki_preferences VALUES ('email_encoding','utf-8');
INSERT INTO tiki_preferences VALUES ('eponymousGroups','n');
INSERT INTO tiki_preferences VALUES ('faq_comments_default_ordering','points_desc');
INSERT INTO tiki_preferences VALUES ('faq_comments_per_page','10');
INSERT INTO tiki_preferences VALUES ('feature_article_comments','n');
INSERT INTO tiki_preferences VALUES ('feature_articles','n');
INSERT INTO tiki_preferences VALUES ('feature_autolinks','y');
INSERT INTO tiki_preferences VALUES ('feature_babelfish_logo','n');
INSERT INTO tiki_preferences VALUES ('feature_babelfish','n');
INSERT INTO tiki_preferences VALUES ('feature_backlinks','y');
INSERT INTO tiki_preferences VALUES ('feature_banners','n');
INSERT INTO tiki_preferences VALUES ('feature_banning','n');
INSERT INTO tiki_preferences VALUES ('feature_blog_comments','n');
INSERT INTO tiki_preferences VALUES ('feature_blogposts_comments','n');
INSERT INTO tiki_preferences VALUES ('feature_blog_rankings','y');
INSERT INTO tiki_preferences VALUES ('feature_blogs','n');
INSERT INTO tiki_preferences VALUES ('feature_bot_bar','y');
INSERT INTO tiki_preferences VALUES ('feature_calendar','n');
INSERT INTO tiki_preferences VALUES ('feature_categories','n');
INSERT INTO tiki_preferences VALUES ('feature_categoryobjects','n');
INSERT INTO tiki_preferences VALUES ('feature_categorypath','n');
INSERT INTO tiki_preferences VALUES ('feature_challenge','n');
INSERT INTO tiki_preferences VALUES ('feature_charts','n');
INSERT INTO tiki_preferences VALUES ('feature_chat','n');
INSERT INTO tiki_preferences VALUES ('feature_clear_passwords','n');
INSERT INTO tiki_preferences VALUES ('feature_cms_rankings','y');
INSERT INTO tiki_preferences VALUES ('feature_cms_templates','n');
INSERT INTO tiki_preferences VALUES ('feature_comm','n');
INSERT INTO tiki_preferences VALUES ('feature_contact','n');
INSERT INTO tiki_preferences VALUES ('feature_custom_home','n');
INSERT INTO tiki_preferences VALUES ('feature_debug_console','n');
INSERT INTO tiki_preferences VALUES ('feature_debugger_console','n');
INSERT INTO tiki_preferences VALUES ('feature_directory','n');
INSERT INTO tiki_preferences VALUES ('feature_drawings','n');
INSERT INTO tiki_preferences VALUES ('feature_dump','n');
INSERT INTO tiki_preferences VALUES ('feature_dynamic_content','n');
INSERT INTO tiki_preferences VALUES ('feature_editcss','n');
INSERT INTO tiki_preferences VALUES ('feature_edit_templates','n');
INSERT INTO tiki_preferences VALUES ('feature_eph','n');
INSERT INTO tiki_preferences VALUES ('feature_faq_comments','y');
INSERT INTO tiki_preferences VALUES ('feature_faqs','n');
INSERT INTO tiki_preferences VALUES ('feature_featuredLinks','y');
INSERT INTO tiki_preferences VALUES ('feature_file_galleries_comments','n');
INSERT INTO tiki_preferences VALUES ('feature_file_galleries','n');
INSERT INTO tiki_preferences VALUES ('feature_file_galleries_rankings','n');
INSERT INTO tiki_preferences VALUES ('feature_forum_parse','y');
INSERT INTO tiki_preferences VALUES ('feature_forum_quickjump','n');
INSERT INTO tiki_preferences VALUES ('feature_forum_rankings','y');
INSERT INTO tiki_preferences VALUES ('feature_forums','n');
INSERT INTO tiki_preferences VALUES ('feature_forum_topicd','n');
INSERT INTO tiki_preferences VALUES ('feature_galleries','y');
INSERT INTO tiki_preferences VALUES ('feature_gal_rankings','y');
INSERT INTO tiki_preferences VALUES ('feature_games','n');
INSERT INTO tiki_preferences VALUES ('feature_history','y');
INSERT INTO tiki_preferences VALUES ('feature_hotwords_nw','n');
INSERT INTO tiki_preferences VALUES ('feature_hotwords','y');
INSERT INTO tiki_preferences VALUES ('feature_html_pages','n');
INSERT INTO tiki_preferences VALUES ('feature_image_galleries_comments','n');
INSERT INTO tiki_preferences VALUES ('feature_integrator','n');
INSERT INTO tiki_preferences VALUES ('feature_lastChanges','y');
INSERT INTO tiki_preferences VALUES ('feature_left_column','y');
INSERT INTO tiki_preferences VALUES ('feature_likePages','y');
INSERT INTO tiki_preferences VALUES ('feature_listPages','y');
INSERT INTO tiki_preferences VALUES ('feature_live_support','n');
INSERT INTO tiki_preferences VALUES ('feature_maps','n');
INSERT INTO tiki_preferences VALUES ('feature_menusfolderstyle','y');
INSERT INTO tiki_preferences VALUES ('feature_messages','n');
INSERT INTO tiki_preferences VALUES ('feature_minical','n');
INSERT INTO tiki_preferences VALUES ('feature_modulecontrols','y');
INSERT INTO tiki_preferences VALUES ('feature_newsletters','n');
INSERT INTO tiki_preferences VALUES ('feature_newsreader','n');
INSERT INTO tiki_preferences VALUES ('feature_notepad','n');
INSERT INTO tiki_preferences VALUES ('feature_obzip','n');
INSERT INTO tiki_preferences VALUES ('feature_page_title','y');
INSERT INTO tiki_preferences VALUES ('feature_phpopentracker','n');
INSERT INTO tiki_preferences VALUES ('feature_poll_comments','n');
INSERT INTO tiki_preferences VALUES ('feature_polls','n');
INSERT INTO tiki_preferences VALUES ('feature_quizzes','n');
INSERT INTO tiki_preferences VALUES ('feature_ranking','n');
INSERT INTO tiki_preferences VALUES ('feature_referer_stats','n');
INSERT INTO tiki_preferences VALUES ('feature_right_column','y');
INSERT INTO tiki_preferences VALUES ('feature_sandbox','y');
INSERT INTO tiki_preferences VALUES ('feature_search_fulltext','y');
INSERT INTO tiki_preferences VALUES ('feature_search_stats','n');
INSERT INTO tiki_preferences VALUES ('feature_search','y');
INSERT INTO tiki_preferences VALUES ('feature_shoutbox','n');
INSERT INTO tiki_preferences VALUES ('feature_smileys','y');
INSERT INTO tiki_preferences VALUES ('feature_stats','n');
INSERT INTO tiki_preferences VALUES ('feature_submissions','n');
INSERT INTO tiki_preferences VALUES ('feature_surveys','n');
INSERT INTO tiki_preferences VALUES ('feature_tasks','n');
INSERT INTO tiki_preferences VALUES ('feature_theme_control','n');
INSERT INTO tiki_preferences VALUES ('feature_top_bar','y');
INSERT INTO tiki_preferences VALUES ('feature_trackers','n');
INSERT INTO tiki_preferences VALUES ('feature_user_bookmarks','n');
INSERT INTO tiki_preferences VALUES ('feature_userfiles','n');
INSERT INTO tiki_preferences VALUES ('feature_usermenu','n');
INSERT INTO tiki_preferences VALUES ('feature_userPreferences','n');
INSERT INTO tiki_preferences VALUES ('feature_userVersions','n');
INSERT INTO tiki_preferences VALUES ('feature_user_watches','n');
INSERT INTO tiki_preferences VALUES ('feature_user_watches_translations','y');
INSERT INTO tiki_preferences VALUES ('feature_view_tpl','n');
INSERT INTO tiki_preferences VALUES ('feature_warn_on_edit','n');
INSERT INTO tiki_preferences VALUES ('feature_webmail','n');
INSERT INTO tiki_preferences VALUES ('feature_wiki_attachments','n');
INSERT INTO tiki_preferences VALUES ('feature_wiki_comments','n');
INSERT INTO tiki_preferences VALUES ('feature_wiki_description','n');
INSERT INTO tiki_preferences VALUES ('feature_wiki_discuss','n');
INSERT INTO tiki_preferences VALUES ('feature_wiki_footnotes','n');
INSERT INTO tiki_preferences VALUES ('feature_wiki_monosp','y');
INSERT INTO tiki_preferences VALUES ('feature_wiki_multiprint','n');
INSERT INTO tiki_preferences VALUES ('feature_wiki_notepad','n');
INSERT INTO tiki_preferences VALUES ('feature_wiki_pdf','n');
INSERT INTO tiki_preferences VALUES ('feature_wiki_pictures','n');
INSERT INTO tiki_preferences VALUES ('feature_wiki_rankings','y');
INSERT INTO tiki_preferences VALUES ('feature_wiki_tables','old');
INSERT INTO tiki_preferences VALUES ('feature_wiki_templates','n');
INSERT INTO tiki_preferences VALUES ('feature_wiki_undo','n');
INSERT INTO tiki_preferences VALUES ('feature_wiki_usrlock','n');
INSERT INTO tiki_preferences VALUES ('feature_wikiwords','y');
INSERT INTO tiki_preferences VALUES ('feature_wiki','y');
INSERT INTO tiki_preferences VALUES ('feature_workflow','n');
INSERT INTO tiki_preferences VALUES ('feature_xmlrpc','n');
INSERT INTO tiki_preferences VALUES ('fgal_list_created','y');
INSERT INTO tiki_preferences VALUES ('fgal_list_description','n');
INSERT INTO tiki_preferences VALUES ('fgal_list_files','y');
INSERT INTO tiki_preferences VALUES ('fgal_list_hits','y');
INSERT INTO tiki_preferences VALUES ('fgal_list_lastmodif','y');
INSERT INTO tiki_preferences VALUES ('fgal_list_name','y');
INSERT INTO tiki_preferences VALUES ('fgal_list_user','y');
INSERT INTO tiki_preferences VALUES ('fgal_match_regex','');
INSERT INTO tiki_preferences VALUES ('fgal_nmatch_regex','');
INSERT INTO tiki_preferences VALUES ('fgal_use_db','y');
INSERT INTO tiki_preferences VALUES ('fgal_use_dir','');
INSERT INTO tiki_preferences VALUES ('file_galleries_comments_default_ordering','points_desc');
INSERT INTO tiki_preferences VALUES ('file_galleries_comments_per_page','10');
INSERT INTO tiki_preferences VALUES ('forgotPass','n');
INSERT INTO tiki_preferences VALUES ('forum_list_desc','y');
INSERT INTO tiki_preferences VALUES ('forum_list_lastpost','y');
INSERT INTO tiki_preferences VALUES ('forum_list_posts','y');
INSERT INTO tiki_preferences VALUES ('forum_list_ppd','n');
INSERT INTO tiki_preferences VALUES ('forum_list_topics','n');
INSERT INTO tiki_preferences VALUES ('forum_list_visits','y');
INSERT INTO tiki_preferences VALUES ('forums_ordering','created_desc');
INSERT INTO tiki_preferences VALUES ('gal_list_created','y');
INSERT INTO tiki_preferences VALUES ('gal_list_description','y');
INSERT INTO tiki_preferences VALUES ('gal_list_imgs','y');
INSERT INTO tiki_preferences VALUES ('gal_list_lastmodif','y');
INSERT INTO tiki_preferences VALUES ('gal_list_name','y');
INSERT INTO tiki_preferences VALUES ('gal_list_user','y');
INSERT INTO tiki_preferences VALUES ('gal_list_visits','y');
INSERT INTO tiki_preferences VALUES ('gal_match_regex','');
INSERT INTO tiki_preferences VALUES ('gal_nmatch_regex','');
INSERT INTO tiki_preferences VALUES ('gal_use_db','y');
INSERT INTO tiki_preferences VALUES ('gal_use_dir','');
INSERT INTO tiki_preferences VALUES ('gal_use_lib','gd');
INSERT INTO tiki_preferences VALUES ('home_file_gallery','');
INSERT INTO tiki_preferences VALUES ('http_domain','');
INSERT INTO tiki_preferences VALUES ('http_port','80');
INSERT INTO tiki_preferences VALUES ('http_prefix','/');
INSERT INTO tiki_preferences VALUES ('https_domain','');
INSERT INTO tiki_preferences VALUES ('https_login','n');
INSERT INTO tiki_preferences VALUES ('https_login_required','n');
INSERT INTO tiki_preferences VALUES ('https_port','443');
INSERT INTO tiki_preferences VALUES ('https_prefix','/');
INSERT INTO tiki_preferences VALUES ('image_galleries_comments_default_orderin','points_desc');
INSERT INTO tiki_preferences VALUES ('image_galleries_comments_per_page','10');
INSERT INTO tiki_preferences VALUES ('keep_versions','1');
INSERT INTO tiki_preferences VALUES ('language','en');
INSERT INTO tiki_preferences VALUES ('lang_use_db','n');
INSERT INTO tiki_preferences VALUES ('layout_section','n');
INSERT INTO tiki_preferences VALUES ('long_date_format','%A %d of %B, %Y');
INSERT INTO tiki_preferences VALUES ('long_time_format','%H:%M:%S %Z');
INSERT INTO tiki_preferences VALUES ('map_path','/var/www/html/map/');
INSERT INTO tiki_preferences VALUES ('maxArticles','10');
INSERT INTO tiki_preferences VALUES ('maxRecords','25');
INSERT INTO tiki_preferences VALUES ('max_rss_directories','10');
INSERT INTO tiki_preferences VALUES ('max_rss_articles','10');
INSERT INTO tiki_preferences VALUES ('max_rss_blog','10');
INSERT INTO tiki_preferences VALUES ('max_rss_blogs','10');
INSERT INTO tiki_preferences VALUES ('max_rss_file_galleries','10');
INSERT INTO tiki_preferences VALUES ('max_rss_file_gallery','10');
INSERT INTO tiki_preferences VALUES ('max_rss_forum','10');
INSERT INTO tiki_preferences VALUES ('max_rss_forums','10');
INSERT INTO tiki_preferences VALUES ('max_rss_image_galleries','10');
INSERT INTO tiki_preferences VALUES ('max_rss_image_gallery','10');
INSERT INTO tiki_preferences VALUES ('max_rss_mapfiles','10');
INSERT INTO tiki_preferences VALUES ('max_rss_wiki','10');
INSERT INTO tiki_preferences VALUES ('maxVersions','0');
INSERT INTO tiki_preferences VALUES ('min_pass_length','1');
INSERT INTO tiki_preferences VALUES ('modallgroups','n');
INSERT INTO tiki_preferences VALUES ('pass_chr_num','n');
INSERT INTO tiki_preferences VALUES ('pass_due','999');
INSERT INTO tiki_preferences VALUES ('poll_comments_default_ordering','points_desc');
INSERT INTO tiki_preferences VALUES ('poll_comments_per_page','10');
INSERT INTO tiki_preferences VALUES ('popupLinks','n');
INSERT INTO tiki_preferences VALUES ('proxy_host','');
INSERT INTO tiki_preferences VALUES ('proxy_port','');
INSERT INTO tiki_preferences VALUES ('record_untranslated','n');
INSERT INTO tiki_preferences VALUES ('registerPasscode','');
INSERT INTO tiki_preferences VALUES ('rememberme','disabled');
INSERT INTO tiki_preferences VALUES ('remembertime','7200');
INSERT INTO tiki_preferences VALUES ('rnd_num_reg','n');
INSERT INTO tiki_preferences VALUES ('rss_directories','y');
INSERT INTO tiki_preferences VALUES ('rss_articles','y');
INSERT INTO tiki_preferences VALUES ('rss_blog','n');
INSERT INTO tiki_preferences VALUES ('rss_blogs','y');
INSERT INTO tiki_preferences VALUES ('rssfeed_creator','');
INSERT INTO tiki_preferences VALUES ('rssfeed_css','y');
INSERT INTO tiki_preferences VALUES ('rssfeed_default_version','2');
INSERT INTO tiki_preferences VALUES ('rssfeed_editor','');
INSERT INTO tiki_preferences VALUES ('rssfeed_language','en-us');
INSERT INTO tiki_preferences VALUES ('rssfeed_publisher','');
INSERT INTO tiki_preferences VALUES ('rssfeed_webmaster','');
INSERT INTO tiki_preferences VALUES ('rss_file_galleries','y');
INSERT INTO tiki_preferences VALUES ('rss_file_gallery','n');
INSERT INTO tiki_preferences VALUES ('rss_forums','y');
INSERT INTO tiki_preferences VALUES ('rss_forum','y');
INSERT INTO tiki_preferences VALUES ('rss_image_galleries','y');
INSERT INTO tiki_preferences VALUES ('rss_image_gallery','n');
INSERT INTO tiki_preferences VALUES ('rss_mapfiles','y');
INSERT INTO tiki_preferences VALUES ('rss_wiki','y');
INSERT INTO tiki_preferences VALUES ('sender_email','');
INSERT INTO tiki_preferences VALUES ('short_date_format','%a %d of %b, %Y');
INSERT INTO tiki_preferences VALUES ('short_time_format','%H:%M %Z');
INSERT INTO tiki_preferences VALUES ('shoutbox_autolink','n');
INSERT INTO tiki_preferences VALUES ('siteTitle','');
INSERT INTO tiki_preferences VALUES ('slide_style','slidestyle.css');
INSERT INTO tiki_preferences VALUES ('style','moreneat.css');
INSERT INTO tiki_preferences VALUES ('system_os','unix');
INSERT INTO tiki_preferences VALUES ('tikiIndex','tiki-index.php');
INSERT INTO tiki_preferences VALUES ('tmpDir','temp');
INSERT INTO tiki_preferences VALUES ('t_use_db','y');
INSERT INTO tiki_preferences VALUES ('t_use_dir','');
INSERT INTO tiki_preferences VALUES ('uf_use_db','y');
INSERT INTO tiki_preferences VALUES ('uf_use_dir','');
INSERT INTO tiki_preferences VALUES ('urlIndex','');
INSERT INTO tiki_preferences VALUES ('use_proxy','n');
INSERT INTO tiki_preferences VALUES ('user_assigned_modules','n');
INSERT INTO tiki_preferences VALUES ('useRegisterPasscode','n');
INSERT INTO tiki_preferences VALUES ('userfiles_quota','30');
INSERT INTO tiki_preferences VALUES ('useUrlIndex','n');
INSERT INTO tiki_preferences VALUES ('validateUsers','n');
INSERT INTO tiki_preferences VALUES ('warn_on_edit_time','2');
INSERT INTO tiki_preferences VALUES ('webmail_max_attachment','1500000');
INSERT INTO tiki_preferences VALUES ('webmail_view_html','y');
INSERT INTO tiki_preferences VALUES ('webserverauth','n');
INSERT INTO tiki_preferences VALUES ('wiki_bot_bar','n');
INSERT INTO tiki_preferences VALUES ('wiki_cache','0');
INSERT INTO tiki_preferences VALUES ('wiki_comments_default_ordering','points_desc');
INSERT INTO tiki_preferences VALUES ('wiki_comments_per_page','10');
INSERT INTO tiki_preferences VALUES ('wiki_creator_admin','n');
INSERT INTO tiki_preferences VALUES ('wiki_feature_copyrights','n');
INSERT INTO tiki_preferences VALUES ('wiki_forum','');
INSERT INTO tiki_preferences VALUES ('wiki_forum_id','');
INSERT INTO tiki_preferences VALUES ('wikiHomePage','HomePage');
INSERT INTO tiki_preferences VALUES ('wiki_left_column','y');
INSERT INTO tiki_preferences VALUES ('wikiLicensePage','');
INSERT INTO tiki_preferences VALUES ('wiki_list_backlinks','y');
INSERT INTO tiki_preferences VALUES ('wiki_list_comment','y');
INSERT INTO tiki_preferences VALUES ('wiki_list_creator','y');
INSERT INTO tiki_preferences VALUES ('wiki_list_hits','y');
INSERT INTO tiki_preferences VALUES ('wiki_list_lastmodif','y');
INSERT INTO tiki_preferences VALUES ('wiki_list_lastver','y');
INSERT INTO tiki_preferences VALUES ('wiki_list_links','y');
INSERT INTO tiki_preferences VALUES ('wiki_list_name','y');
INSERT INTO tiki_preferences VALUES ('wiki_list_size','y');
INSERT INTO tiki_preferences VALUES ('wiki_list_status','y');
INSERT INTO tiki_preferences VALUES ('wiki_list_user','y');
INSERT INTO tiki_preferences VALUES ('wiki_list_versions','y');
INSERT INTO tiki_preferences VALUES ('wiki_page_regex','strict');
INSERT INTO tiki_preferences VALUES ('wiki_right_column','y');
INSERT INTO tiki_preferences VALUES ('wiki_spellcheck','n');
INSERT INTO tiki_preferences VALUES ('wikiSubmitNotice','');
INSERT INTO tiki_preferences VALUES ('wiki_top_bar','n');
INSERT INTO tiki_preferences VALUES ('w_use_db','y');
INSERT INTO tiki_preferences VALUES ('w_use_dir','');
INSERT INTO users_groups VALUES ('Anonymous','Public users not logged',NULL);
INSERT INTO users_groups VALUES ('Registered','Users logged into the system',NULL);
INSERT INTO users_permissions VALUES ('tiki_p_abort_instance','Can abort a process instance','editors','workflow');
INSERT INTO users_permissions VALUES ('tiki_p_access_closed_site','Can access site when closed','admin','tiki');
INSERT INTO users_permissions VALUES ('tiki_p_add_events','Can add events in the calendar','registered','calendar');
INSERT INTO users_permissions VALUES ('tiki_p_admin','Administrator, can manage users groups and permissions, Hotwords and all the weblog features','admin','tiki');
INSERT INTO users_permissions VALUES ('tiki_p_admin_banners','Administrator, can admin banners','admin','tiki');
INSERT INTO users_permissions VALUES ('tiki_p_admin_banning','Can ban users or ips','admin','tiki');
INSERT INTO users_permissions VALUES ('tiki_p_admin_calendar','Can create/admin calendars','admin','calendar');
INSERT INTO users_permissions VALUES ('tiki_p_admin_categories','Can admin categories','editors','tiki');
INSERT INTO users_permissions VALUES ('tiki_p_admin_charts','Can admin charts','admin','charts');
INSERT INTO users_permissions VALUES ('tiki_p_admin_chat','Administrator, can create channels remove channels etc','editors','chat');
INSERT INTO users_permissions VALUES ('tiki_p_admin_cms','Can admin the cms','editors','cms');
INSERT INTO users_permissions VALUES ('tiki_p_admin_directory','Can admin the directory','editors','directory');
INSERT INTO users_permissions VALUES ('tiki_p_admin_directory_cats','Can admin directory categories','editors','directory');
INSERT INTO users_permissions VALUES ('tiki_p_admin_directory_sites','Can admin directory sites','editors','directory');
INSERT INTO users_permissions VALUES ('tiki_p_admin_drawings','Can admin drawings','editors','drawings');
INSERT INTO users_permissions VALUES ('tiki_p_admin_dynamic','Can admin the dynamic content system','editors','tiki');
INSERT INTO users_permissions VALUES ('tiki_p_admin_faqs','Can admin faqs','editors','faqs');
INSERT INTO users_permissions VALUES ('tiki_p_admin_file_galleries','Can admin file galleries','editors','file galleries');
INSERT INTO users_permissions VALUES ('tiki_p_admin_forum','Can admin forums','editors','forums');
INSERT INTO users_permissions VALUES ('tiki_p_admin_galleries','Can admin Image Galleries','editors','image galleries');
INSERT INTO users_permissions VALUES ('tiki_p_admin_games','Can admin games','editors','games');
INSERT INTO users_permissions VALUES ('tiki_p_admin_integrator','Can admin integrator repositories and rules','admin','tiki');
INSERT INTO users_permissions VALUES ('tiki_p_admin_mailin','Can admin mail-in accounts','admin','tiki');
INSERT INTO users_permissions VALUES ('tiki_p_admin_newsletters','Can admin newsletters','editors','newsletters');
INSERT INTO users_permissions VALUES ('tiki_p_admin_quizzes','Can admin quizzes','editors','quizzes');
INSERT INTO users_permissions VALUES ('tiki_p_admin_received_articles','Can admin received articles','editors','comm');
INSERT INTO users_permissions VALUES ('tiki_p_admin_received_pages','Can admin received pages','editors','comm');
INSERT INTO users_permissions VALUES ('tiki_p_admin_shoutbox','Can admin shoutbox (Edit/remove msgs)','editors','shoutbox');
INSERT INTO users_permissions VALUES ('tiki_p_admin_surveys','Can admin surveys','editors','surveys');
INSERT INTO users_permissions VALUES ('tiki_p_admin_trackers','Can admin trackers','editors','trackers');
INSERT INTO users_permissions VALUES ('tiki_p_admin_wiki','Can admin the wiki','editors','wiki');
INSERT INTO users_permissions VALUES ('tiki_p_admin_workflow','Can admin workflow processes','admin','workflow');
INSERT INTO users_permissions VALUES ('tiki_p_approve_submission','Can approve submissions','editors','cms');
INSERT INTO users_permissions VALUES ('tiki_p_attach_trackers','Can attach files to tracker items','registered','trackers');
INSERT INTO users_permissions VALUES ('tiki_p_autoapprove_submission','Submited articles automatically approved','editors','cms');
INSERT INTO users_permissions VALUES ('tiki_p_autosubmit_link','Submited links are valid','editors','directory');
INSERT INTO users_permissions VALUES ('tiki_p_autoval_chart_suggestio','Autovalidate suggestions','editors','charts');
INSERT INTO users_permissions VALUES ('tiki_p_batch_upload_files','Can upload zip files with files','editors','file galleries');
INSERT INTO users_permissions VALUES ('tiki_p_batch_upload_images','Can upload zip files with images','editors','image galleries');
INSERT INTO users_permissions VALUES ('tiki_p_blog_admin','Can admin blogs','editors','blogs');
INSERT INTO users_permissions VALUES ('tiki_p_blog_post','Can post to a blog','registered','blogs');
INSERT INTO users_permissions VALUES ('tiki_p_broadcast_all','Can broadcast messages to all user','admin','messu');
INSERT INTO users_permissions VALUES ('tiki_p_broadcast','Can broadcast messages to groups','admin','messu');
INSERT INTO users_permissions VALUES ('tiki_p_cache_bookmarks','Can cache user bookmarks','registered','user');
INSERT INTO users_permissions VALUES ('tiki_p_change_events','Can change events in the calendar','registered','calendar');
INSERT INTO users_permissions VALUES ('tiki_p_chat','Can use the chat system','registered','chat');
INSERT INTO users_permissions VALUES ('tiki_p_comment_tracker_items','Can insert comments for tracker items','basic','trackers');
INSERT INTO users_permissions VALUES ('tiki_p_configure_modules','Can configure modules','registered','user');
INSERT INTO users_permissions VALUES ('tiki_p_create_blogs','Can create a blog','editors','blogs');
INSERT INTO users_permissions VALUES ('tiki_p_create_bookmarks','Can create user bookmarksche user bookmarks','registered','user');
INSERT INTO users_permissions VALUES ('tiki_p_create_css','Can create new css suffixed with -user','registered','tiki');
INSERT INTO users_permissions VALUES ('tiki_p_create_file_galleries','Can create file galleries','editors','file galleries');
INSERT INTO users_permissions VALUES ('tiki_p_create_galleries','Can create image galleries','editors','image galleries');
INSERT INTO users_permissions VALUES ('tiki_p_create_tracker_items','Can create new items for trackers','registered','trackers');
INSERT INTO users_permissions VALUES ('tiki_p_download_files','Can download files','basic','file galleries');
INSERT INTO users_permissions VALUES ('tiki_p_edit_article','Can edit articles','editors','cms');
INSERT INTO users_permissions VALUES ('tiki_p_edit','Can edit pages','registered','wiki');
INSERT INTO users_permissions VALUES ('tiki_p_edit_comments','Can edit all comments','editors','comments');
INSERT INTO users_permissions VALUES ('tiki_p_edit_content_templates','Can edit content templates','editors','content templates');
INSERT INTO users_permissions VALUES ('tiki_p_edit_cookies','Can admin cookies','editors','tiki');
INSERT INTO users_permissions VALUES ('tiki_p_edit_copyrights','Can edit copyright notices','editors','wiki');
INSERT INTO users_permissions VALUES ('tiki_p_edit_drawings','Can edit drawings','basic','drawings');
INSERT INTO users_permissions VALUES ('tiki_p_edit_dynvar','Can edit dynamic variables','editors','wiki');
INSERT INTO users_permissions VALUES ('tiki_p_edit_html_pages','Can edit HTML pages','editors','html pages');
INSERT INTO users_permissions VALUES ('tiki_p_edit_languages','Can edit translations and create new languages','editors','tiki');
INSERT INTO users_permissions VALUES ('tiki_p_edit_structures','Can create and edit structures','editors','wiki');
INSERT INTO users_permissions VALUES ('tiki_p_edit_submission','Can edit submissions','editors','cms');
INSERT INTO users_permissions VALUES ('tiki_p_edit_templates','Can edit site templates','admin','tiki');
INSERT INTO users_permissions VALUES ('tiki_p_view_templates','Can view site templates','admin','tiki');
INSERT INTO users_permissions VALUES ('tiki_p_eph_admin','Can admin ephemerides','editors','tiki');
INSERT INTO users_permissions VALUES ('tiki_p_exception_instance','Can declare an instance as exception','registered','workflow');
INSERT INTO users_permissions VALUES ('tiki_p_forum_attach','Can attach to forum posts','registered','forums');
INSERT INTO users_permissions VALUES ('tiki_p_forum_autoapp','Auto approve forum posts','editors','forums');
INSERT INTO users_permissions VALUES ('tiki_p_forum_post','Can post in forums','registered','forums');
INSERT INTO users_permissions VALUES ('tiki_p_forum_post_topic','Can start threads in forums','registered','forums');
INSERT INTO users_permissions VALUES ('tiki_p_forum_read','Can read forums','basic','forums');
INSERT INTO users_permissions VALUES ('tiki_p_forums_report','Can report msgs to moderator','registered','forums');
INSERT INTO users_permissions VALUES ('tiki_p_forum_vote','Can vote comments in forums','registered','forums');
INSERT INTO users_permissions VALUES ('tiki_p_live_support_admin','Admin live support system','admin','support');
INSERT INTO users_permissions VALUES ('tiki_p_live_support','Can use live support system','basic','support');
INSERT INTO users_permissions VALUES ('tiki_p_lock','Can lock pages','editors','wiki');
INSERT INTO users_permissions VALUES ('tiki_p_map_create','Can create new mapfile','admin','maps');
INSERT INTO users_permissions VALUES ('tiki_p_map_delete','Can delete mapfiles','admin','maps');
INSERT INTO users_permissions VALUES ('tiki_p_map_edit','Can edit mapfiles','editor','maps');
INSERT INTO users_permissions VALUES ('tiki_p_map_view','Can view mapfiles','basic','maps');
INSERT INTO users_permissions VALUES ('tiki_p_messages','Can use the messaging system','registered','messu');
INSERT INTO users_permissions VALUES ('tiki_p_minical','Can use the mini event calendar','registered','user');
INSERT INTO users_permissions VALUES ('tiki_p_minor','Can save as minor edit','registered','wiki');
INSERT INTO users_permissions VALUES ('tiki_p_modify_tracker_items','Can change tracker items','registered','trackers');
INSERT INTO users_permissions VALUES ('tiki_p_newsreader','Can use the newsreader','registered','user');
INSERT INTO users_permissions VALUES ('tiki_p_notepad','Can use the notepad','registered','user');
INSERT INTO users_permissions VALUES ('tiki_p_play_games','Can play games','basic','games');
INSERT INTO users_permissions VALUES ('tiki_p_post_comments','Can post new comments','registered','comments');
INSERT INTO users_permissions VALUES ('tiki_p_post_shoutbox','Can post messages in shoutbox','basic','shoutbox');
INSERT INTO users_permissions VALUES ('tiki_p_read_article','Can read articles','basic','cms');
INSERT INTO users_permissions VALUES ('tiki_p_read_blog','Can read blogs','basic','blogs');
INSERT INTO users_permissions VALUES ('tiki_p_read_comments','Can read comments','basic','comments');
INSERT INTO users_permissions VALUES ('tiki_p_remove_article','Can remove articles','editors','cms');
INSERT INTO users_permissions VALUES ('tiki_p_remove','Can remove','editors','wiki');
INSERT INTO users_permissions VALUES ('tiki_p_remove_comments','Can delete comments','editors','comments');
INSERT INTO users_permissions VALUES ('tiki_p_remove_submission','Can remove submissions','editors','cms');
INSERT INTO users_permissions VALUES ('tiki_p_rename','Can rename pages','editors','wiki');
INSERT INTO users_permissions VALUES ('tiki_p_rollback','Can rollback pages','editors','wiki');
INSERT INTO users_permissions VALUES ('tiki_p_send_articles','Can send articles to other sites','editors','comm');
INSERT INTO users_permissions VALUES ('tiki_p_send_instance','Can send instances after completion','registered','workflow');
INSERT INTO users_permissions VALUES ('tiki_p_sendme_articles','Can send articles to this site','registered','comm');
INSERT INTO users_permissions VALUES ('tiki_p_sendme_pages','Can send pages to this site','registered','comm');
INSERT INTO users_permissions VALUES ('tiki_p_send_pages','Can send pages to other sites','registered','comm');
INSERT INTO users_permissions VALUES ('tiki_p_submit_article','Can submit articles','basic','cms');
INSERT INTO users_permissions VALUES ('tiki_p_submit_link','Can submit sites to the directory','basic','directory');
INSERT INTO users_permissions VALUES ('tiki_p_subscribe_email','Can subscribe any email to newsletters','editors','newsletters');
INSERT INTO users_permissions VALUES ('tiki_p_subscribe_newsletters','Can subscribe to newsletters','basic','newsletters');
INSERT INTO users_permissions VALUES ('tiki_p_suggest_chart_item','Can suggest items','basic','charts');
INSERT INTO users_permissions VALUES ('tiki_p_suggest_faq','Can suggest faq questions','basic','faqs');
INSERT INTO users_permissions VALUES ('tiki_p_take_quiz','Can take quizzes','basic','quizzes');
INSERT INTO users_permissions VALUES ('tiki_p_take_survey','Can take surveys','basic','surveys');
INSERT INTO users_permissions VALUES ('tiki_p_tasks','Can use tasks','registered','user');
INSERT INTO users_permissions VALUES ('tiki_p_topic_read','Can read a topic (Applies only to individual topic perms)','basic','topics');
INSERT INTO users_permissions VALUES ('tiki_p_upload_files','Can upload files','registered','file galleries');
INSERT INTO users_permissions VALUES ('tiki_p_upload_images','Can upload images','registered','image galleries');
INSERT INTO users_permissions VALUES ('tiki_p_upload_picture','Can upload pictures to wiki pages','registered','wiki');
INSERT INTO users_permissions VALUES ('tiki_p_use_content_templates','Can use content templates','registered','content templates');
INSERT INTO users_permissions VALUES ('tiki_p_use_HTML','Can use HTML in pages','editors','tiki');
INSERT INTO users_permissions VALUES ('tiki_p_userfiles','Can upload personal files','registered','user');
INSERT INTO users_permissions VALUES ('tiki_p_usermenu','Can create items in personal menu','registered','user');
INSERT INTO users_permissions VALUES ('tiki_p_use_webmail','Can use webmail','registered','webmail');
INSERT INTO users_permissions VALUES ('tiki_p_use_workflow','Can execute workflow activities','registered','workflow');
INSERT INTO users_permissions VALUES ('tiki_p_validate_links','Can validate submited links','editors','directory');
INSERT INTO users_permissions VALUES ('tiki_p_view_calendar','Can browse the calendar','basic','calendar');
INSERT INTO users_permissions VALUES ('tiki_p_view','Can view page/pages','basic','wiki');
INSERT INTO users_permissions VALUES ('tiki_p_view_categories','Can browse categories','registered','tiki');
INSERT INTO users_permissions VALUES ('tiki_p_view_chart','Can view charts','basic','charts');
INSERT INTO users_permissions VALUES ('tiki_p_view_directory','Can use the directory','basic','directory');
INSERT INTO users_permissions VALUES ('tiki_p_view_eph','Can view ephemerides','registered','tiki');
INSERT INTO users_permissions VALUES ('tiki_p_view_faqs','Can view faqs','basic','faqs');
INSERT INTO users_permissions VALUES ('tiki_p_view_file_gallery','Can view file galleries','basic','file galleries');
INSERT INTO users_permissions VALUES ('tiki_p_view_html_pages','Can view HTML pages','basic','html pages');
INSERT INTO users_permissions VALUES ('tiki_p_view_image_gallery','Can view image galleries','basic','image galleries');
INSERT INTO users_permissions VALUES ('tiki_p_view_integrator','Can view integrated repositories','basic','tiki');
INSERT INTO users_permissions VALUES ('tiki_p_view_quiz_stats','Can view quiz stats','basic','quizzes');
INSERT INTO users_permissions VALUES ('tiki_p_view_referer_stats','Can view referer stats','editors','tiki');
INSERT INTO users_permissions VALUES ('tiki_p_view_shoutbox','Can view shoutbox','basic','shoutbox');
INSERT INTO users_permissions VALUES ('tiki_p_view_stats','Can view site stats','basic','tiki');
INSERT INTO users_permissions VALUES ('tiki_p_view_survey_stats','Can view survey stats','basic','surveys');
INSERT INTO users_permissions VALUES ('tiki_p_view_trackers','Can view trackers','basic','trackers');
INSERT INTO users_permissions VALUES ('tiki_p_view_user_results','Can view user quiz results','editors','quizzes');
INSERT INTO users_permissions VALUES ('tiki_p_vote_chart','Can vote','basic','charts');
INSERT INTO users_permissions VALUES ('tiki_p_vote_comments','Can vote comments','registered','comments');
INSERT INTO users_permissions VALUES ('tiki_p_vote_poll','Can vote polls','basic','tiki');
INSERT INTO users_permissions VALUES ('tiki_p_wiki_admin_attachments','Can admin attachments to wiki pages','editors','wiki');
INSERT INTO users_permissions VALUES ('tiki_p_wiki_attach_files','Can attach files to wiki pages','registered','wiki');
INSERT INTO users_permissions VALUES ('tiki_p_wiki_view_attachments','Can view wiki attachments and download','registered','wiki');
